##load libraries
library(ggplot2)
library(grid)
library(xtable)


###############################################
###############################################
## Performance Time without Timeouts and Errors
###############################################
###############################################

## load table
readith <- read.csv(file="no_timeouts_no_errors.csv", head=TRUE, sep=",");

## compute the logarithm of the performance time and add it to the dataset
readith$Secs <- readith$Time/60
readith$logSecs <- log10(readith$Secs)

## general linear model for logarithm of time dependent on rule type and clutter amount
linearFit <- glm(logSecs ~ CRule*Clutter, data=readith)
## anova test 
result <- anova(linearFit,test="F")


## compute means and standard deviation of time per rule and clutter amount and merge it into a single table
clmeans <- aggregate(Time/60 ~ CRule+Clutter, readith, mean)
names(clmeans)[names(clmeans)=="Time/60"] <- "Time"
clsd <- aggregate(Time/60 ~ CRule+Clutter, readith, sd)
names(clsd)[names(clsd)=="Time/60"] <- "SD Time"
clmeans <- merge(clmeans, clsd, by=c("CRule", "Clutter"))

onlyclmeans <- aggregate(Time/60 ~ Clutter, readith, mean)
names(onlyclmeans)[names(onlyclmeans)=="Time/60"] <- "Time"
onlyclsd <- aggregate(Time/60 ~ Clutter, readith, sd)
names(onlyclsd)[names(onlyclsd)=="Time/60"] <- "SD Time"
onlyclmeans <- merge(onlyclmeans, onlyclsd, by=c( "Clutter"))

onlyRmeans <- aggregate(Time/60 ~ CRule, readith, mean)
names(onlyRmeans)[names(onlyRmeans)=="Time/60"] <- "Time"
onlyRsd <- aggregate(Time/60 ~ CRule, readith, sd)
names(onlyRsd)[names(onlyRsd)=="Time/60"] <- "SD Time"
onlyRmeans <- merge(onlyRmeans, onlyRsd, by=c( "CRule"))



###############################################
## Output plots
###############################################

diagrams_theme = theme(panel.grid.major = element_line(size = 0.5, color = "grey"), 
    axis.line = element_line(size = 0.7, color = "black"), legend.position = c(0.85, 
        0.7), text = element_text(size = 14))

## boxplot of the time (in seconds) needed per rule
timeBoxPlot <- ggplot( readith, aes(x=CRule, y=Secs),ymin=0, ymax=120)+
            ylab("Time/s")+
        scale_x_discrete(name = "Proof Rule", labels = c("Combine", "Copy\nContour", "Copy\nShading", "Erase\nContour", "Erase\n Shading"))+
                    theme_bw() +diagrams_theme+
    geom_boxplot(position=position_dodge(0.9), width=.15, binwidth=0)
print(timeBoxPlot)
ggsave("time_rule_boxplot.pdf", width=4.5, height=6)


pdf("time_probability.pdf", useDingbats=FALSE)
qqnorm(residuals(linearFit), ylab="Residuals of log(Time)")
qqline(residuals(linearFit))
dev.off()
 
## boxplot of the time (in seconds) needed per clutter 
timeBoxPlot <- ggplot( readith, aes(x=Clutter, y=Secs), width=.15)+
    geom_boxplot(width=.15)+
        coord_cartesian(ylim = c(0, 120))+
        coord_fixed(ratio = 0.055)+
            ylab("Time/s")+

                theme_bw() +  scale_x_discrete("Clutter", labels=c("H"="High", "L"="Low")) +diagrams_theme 

print(timeBoxPlot)
ggsave("time_clutter_boxplot.pdf", width=3, height=6)


 
## interaction plot
interact <- ggplot(clmeans, aes(x=CRule, y=Time, colour=Clutter, shape=Clutter))+
    scale_x_discrete(name ="Proof Rule",labels = c("Combine", "Copy\nContour", "Copy\nShading", "Erase\nContour", "Erase\n Shading")) +
    scale_y_continuous("Mean Performance Time/s")+    
     theme_bw()+ diagrams_theme+
    geom_point(size=3)+
        geom_line(data =clmeans, aes(y = Time, group = Clutter))+
scale_color_discrete(name = "Clutter", labels = c("High", "Low"), c=300,l=30)+
scale_shape_discrete(name = "Clutter", labels = c("High", "Low"))
print(interact)
ggsave("time_rule_vs_clutter.pdf",width=5, height=4)

interact2 <- ggplot(clmeans, aes(x=Clutter, y=Time, colour=CRule, shape=CRule))+
    scale_x_discrete("Amount of Clutter")+
    scale_y_continuous("Mean Performance Time/s", limits=c(10,60))+    
        theme_bw()+ diagrams_theme+
            theme( legend.position = c(0.8, 0.8))+
         geom_point(size=3)+
             geom_line(data =clmeans, aes(y = Time, group = CRule))+
scale_color_discrete(name = "Proof Rule", labels = c("Combine", "Copy Contour", "Copy Shading", "Erase Contour", "Erase Shading"), c=100,l=55)+
scale_shape_discrete(name = "Proof Rule", labels = c("Combine", "Copy Contour", "Copy Shading", "Erase Contour", "Erase Shading"))
print(interact2)
ggsave("time_clutter_vs_rule.pdf", width =4.5,height=4.5)
